grib2io.tables.section5 API documentation

# grib2io.tables.section5

View Source

     1table_5_0 = {
     2'0':'Grid Point Data - Simple Packing (see Template 5.0)',
     3'1':'Matrix Value at Grid Point - Simple Packing (see Template 5.1)',
     4'2':'Grid Point Data - Complex Packing (see Template 5.2)',
     5'3':'Grid Point Data - Complex Packing and Spatial Differencing (see Template 5.3)',
     6'4':'Grid Point Data - IEEE Floating Point Data  (see Template 5.4)',
     7'5-39':'Reserved',
     8'40':'Grid Point Data - JPEG2000 Compression (see Template 5.40)',
     9'41':'Grid Point Data - PNG Compression (see Template 5.41)',
    10'42-49':'Reserved',
    11'50':'Spectral Data - Simple Packing (see Template 5.50)',
    12'51':'Spectral Data - Complex Packing (see Template 5.51)',
    13'52-60':'Reserved',
    14'61':'Grid Point Data - Simple Packing With Logarithm Pre-processing  (see Template 5.61)',
    15'62-199':'Reserved',
    16'200':'Run Length Packing With Level Values  (see Template 5.200)',
    17'201-49151':'Reserved',
    18'49152-65534':'Reserved for Local Use',
    19'65535':'Missing',
    20}
    21
    22table_5_1 = {
    23'0':'Floating Point',
    24'1':'Integer',
    25'2-191':'Reserved',
    26'192-254':'Reserved for Local Use',
    27'255':'Missing',
    28}
    29
    30table_5_2 = {
    31'0':'Explicit Coordinate Values Set',
    32'1':'Linear Coordinates  f(1) = C1 f(n) = f(n-1) + C2',
    33'2-10':'Reserved',
    34'11':'Geometric Coordinates  f(1) = C1 f(n) = C2 x f(n-1)',
    35'12-191':'Reserved',
    36'192-254':'Reserved for Local Use',
    37'255':'Missing',
    38}
    39
    40table_5_3 = {
    41'0':'Reserved',
    42'1':'Direction Degrees True',
    43'2':'Frequency (s-1)',
    44'3':'Radial Number (2pi/lamda) (m-1)',
    45'4-191':'Reserved',
    46'192-254':'Reserved for Local Use',
    47'255':'Missing',
    48}
    49
    50table_5_4 = {
    51'0':'Row by Row Splitting',
    52'1':'General Group Splitting',
    53'2-191':'Reserved',
    54'192-254':'Reserved for Local Use',
    55'255':'Missing',
    56}
    57
    58table_5_5 = {
    59'0':'No explicit missing values included within the data values',
    60'1':'Primary missing values included within the data values',
    61'2':'Primary and secondary missing values included within the data values',
    62'3-191':'Reserved',
    63'192-254':'Reserved for Local Use',
    64}
    65
    66table_5_6 = {
    67'0':'Reserved',
    68'1':'First-Order Spatial Differencing',
    69'2':'Second-Order Spatial Differencing',
    70'3-191':'Reserved',
    71'192-254':'Reserved for Local Use',
    72'255':'Missing',
    73}
    74
    75table_5_7 = {
    76'0':'Reserved',
    77'1':'IEEE 32-bit (I=4 in Section 7)',
    78'2':'IEEE 64-bit (I=8 in Section 7)',
    79'3':'IEEE 128-bit (I=16 in Section 7)',
    80'4-254':'Reserved',
    81'255':'Missing',
    82}
    83
    84table_5_40 = {
    85'0':'Lossless',
    86'1':'Lossy',
    87'2-254':'Reserved',
    88'255':'Missing',
    89}